@@ -15,7 +15,7 @@
  * @category   Zend
  * @package    Zend_Tool
  * @subpackage Framework
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @version    $Id$
  */
@@ -26,7 +26,7 @@
  * @category   Zend
  * @package    Zend_Tool
  * @subpackage Framework
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class ZF
@@ -148,17 +148,17 @@ class ZF
             $mode = 'runSetup';
         } elseif ($arguments[0] == '--info') {
             $mode = 'runInfo';
-    	}
-    	
-    	return $mode;
+        }
+        
+        return $mode;
     }
     
 
     /**
      * _detectHomeDirectory() - detect the home directory in a variety of different places
      * 
-     * @param $mustExist Should the returned value already exist in the file system
-     * @param $returnMessages Should it log messages for output later
+     * @param bool $mustExist Should the returned value already exist in the file system
+     * @param bool $returnMessages Should it log messages for output later
      * @return string
      */
     protected function _detectHomeDirectory($mustExist = true, $returnMessages = true)
@@ -215,8 +215,8 @@ class ZF
     /**
      * _detectStorageDirectory() - Detect where the storage directory is from a variaty of possiblities
      * 
-     * @param $mustExist Should the returned value already exist in the file system
-     * @param $returnMessages Should it log messages for output later
+     * @param bool $mustExist Should the returned value already exist in the file system
+     * @param bool $returnMessages Should it log messages for output later
      * @return string
      */
     protected function _detectStorageDirectory($mustExist = true, $returnMessages = true)
@@ -251,8 +251,8 @@ class ZF
     /**
      * _detectConfigFile() - Detect config file location from a variety of possibilities
      * 
-     * @param $mustExist Should the returned value already exist in the file system
-     * @param $returnMessages Should it log messages for output later
+     * @param bool $mustExist Should the returned value already exist in the file system
+     * @param bool $returnMessages Should it log messages for output later
      * @return string
      */
     protected function _detectConfigFile($mustExist = true, $returnMessages = true)
@@ -302,14 +302,15 @@ class ZF
      */
     protected function _setupPHPRuntime()
     {
-    	// set php runtime settings
-    	ini_set('display_errors', true);
-    	
+        // set php runtime settings
+        ini_set('display_errors', true);
+        
         // support the changing of the current working directory, necessary for some providers
-        if (isset($_ENV['ZEND_TOOL_CURRENT_WORKING_DIRECTORY'])) {
-            chdir($_ENV['ZEND_TOOL_CURRENT_WORKING_DIRECTORY']);
+        $cwd = getenv('ZEND_TOOL_CURRENT_WORKING_DIRECTORY');
+        if ($cwd != '' && realpath($cwd)) {
+            chdir($cwd);
         }
-    	
+        
         if (!$this->_configFile) {
             return;
         }
@@ -323,8 +324,6 @@ class ZF
                 }
             }
         }
-
-        return null;
     }
     
     /**
@@ -368,8 +367,6 @@ class ZF
             $this->_mode = 'runError';
             return;
         }
-        
-        return null;
     }
     
     /**
@@ -413,8 +410,8 @@ is inside your include_path.  There are a variety of ways that you can
 ensure that this zf command line tool knows where the Zend Framework
 library is on your system, but not all of them can be described here.
 
-The easiest way to get the zf command running is to allow is to give it
-the include path via an environment variable ZEND_TOOL_INCLUDE_PATH or
+The easiest way to get the zf command running is to give it the include 
+path via an environment variable ZEND_TOOL_INCLUDE_PATH or 
 ZEND_TOOL_INCLUDE_PATH_PREPEND with the proper include path to use,
 then run the command "zf --setup".  This command is designed to create
 a storage location for your user, as well as create the zf.ini file
@@ -429,7 +426,6 @@ Your are encourged to read more in the link that follows.
 
 EOS;
 
-        return null;
     }
     
     /**
@@ -474,8 +470,6 @@ EOS;
                 $this->_runSetupMoreInfo();
                 break;
         }
-        
-        return null;
     }
 
     /**
@@ -527,8 +521,6 @@ EOS;
         }
         
         echo 'Config file written to ' . $configFile . PHP_EOL;
-        
-        return null;
     }
 
     /**
@@ -592,28 +584,27 @@ EOS;
      */
     protected function _runTool()
     {
-	    
-	    $configOptions = array();
-	    if (isset($this->_configFile) && $this->_configFile) {
-	        $configOptions['configOptions']['configFilepath'] = $this->_configFile;
-	    }
-	    if (isset($this->_storageDirectory) && $this->_storageDirectory) {
-	        $configOptions['storageOptions']['directory'] = $this->_storageDirectory;
-	    }
-	    
-	    // ensure that zf.php loads the Zend_Tool_Project features
-	    $configOptions['classesToLoad'] = 'Zend_Tool_Project_Provider_Manifest';
-	    
-	    $console = new Zend_Tool_Framework_Client_Console($configOptions);
-	    $console->dispatch();
-		return null;
+        
+        $configOptions = array();
+        if (isset($this->_configFile) && $this->_configFile) {
+            $configOptions['configOptions']['configFilepath'] = $this->_configFile;
+        }
+        if (isset($this->_storageDirectory) && $this->_storageDirectory) {
+            $configOptions['storageOptions']['directory'] = $this->_storageDirectory;
+        }
+        
+        // ensure that zf.php loads the Zend_Tool_Project features
+        $configOptions['classesToLoad'] = 'Zend_Tool_Project_Provider_Manifest';
+        
+        $console = new Zend_Tool_Framework_Client_Console($configOptions);
+        $console->dispatch();
     }
 
     /**
      * _logMessage() - Internal method used to log setup and information messages.
      * 
-     * @param $message
-     * @param $storeMessage
+     * @param string $message
+     * @param bool   $storeMessage
      * @return void
      */
     protected function _logMessage($message, $storeMessage = true)
@@ -631,5 +622,3 @@ EOS;
 if (!getenv('ZF_NO_MAIN')) {
     ZF::main();
 }
-
-
