@@ -14,9 +14,9 @@
  *
  * @category   Zend
  * @package    Zend_Controller
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: Abstract.php 17708 2009-08-21 13:43:39Z matthew $
+ * @version    $Id: Abstract.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 /**
@@ -26,7 +26,7 @@
  *
  * @package Zend_Controller
  * @subpackage Response
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 abstract class Zend_Controller_Response_Abstract
@@ -87,8 +87,8 @@ abstract class Zend_Controller_Response_Abstract
      * Normalize a header name
      *
      * Normalizes a header name to X-Capitalized-Names
-     * 
-     * @param  string $name 
+     *
+     * @param  string $name
      * @return string
      */
     protected function _normalizeHeader($name)
@@ -184,6 +184,27 @@ abstract class Zend_Controller_Response_Abstract
         return $this;
     }
 
+    /**
+     * Clears the specified HTTP header
+     *
+     * @param  string $name
+     * @return Zend_Controller_Response_Abstract
+     */
+    public function clearHeader($name)
+    {
+        if (! count($this->_headers)) {
+            return $this;
+        }
+
+        foreach ($this->_headers as $index => $header) {
+            if ($name == $header['name']) {
+                unset($this->_headers[$index]);
+            }
+        }
+
+        return $this;
+    }
+
     /**
      * Set raw HTTP header
      *
@@ -223,6 +244,24 @@ abstract class Zend_Controller_Response_Abstract
         return $this;
     }
 
+    /**
+     * Clears the specified raw HTTP header
+     *
+     * @param  string $headerRaw
+     * @return Zend_Controller_Response_Abstract
+     */
+    public function clearRawHeader($headerRaw)
+    {
+        if (! count($this->_headersRaw)) {
+            return $this;
+        }
+
+        $key = array_search($headerRaw, $this->_headersRaw);
+        unset($this->_headersRaw[$key]);
+
+        return $this;
+    }
+
     /**
      * Clear all headers, normal and raw
      *
