@@ -14,9 +14,9 @@
  *
  * @category   Zend
  * @package    Zend_Version
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: Version.php 21181 2010-02-23 22:02:38Z matthew $
+ * @version    $Id: Version.php 23849 2011-04-06 15:23:21Z matthew $
  */
 
 /**
@@ -24,7 +24,7 @@
  *
  * @category   Zend
  * @package    Zend_Version
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 final class Zend_Version
@@ -32,14 +32,21 @@ final class Zend_Version
     /**
      * Zend Framework version identification - see compareVersion()
      */
-    const VERSION = '1.10.3';
+    const VERSION = '1.11.5';
+
+    /**
+     * The latest stable version Zend Framework available
+     *
+     * @var string
+     */
+    protected static $_lastestVersion;
 
     /**
      * Compare the specified Zend Framework version string $version
      * with the current Zend_Version::VERSION of Zend Framework.
      *
      * @param  string  $version  A version string (e.g. "0.7.1").
-     * @return boolean           -1 if the $version is older,
+     * @return int           -1 if the $version is older,
      *                           0 if they are the same,
      *                           and +1 if $version is newer.
      *
@@ -50,4 +57,25 @@ final class Zend_Version
         $version = preg_replace('/(\d)pr(\d?)/', '$1a$2', $version);
         return version_compare($version, strtolower(self::VERSION));
     }
+
+    /**
+     * Fetches the version of the latest stable release
+     *
+     * @link http://framework.zend.com/download/latest
+     * @return string
+     */
+    public static function getLatest()
+    {
+        if (null === self::$_lastestVersion) {
+            self::$_lastestVersion = 'not available';
+
+            $handle = fopen('http://framework.zend.com/api/zf-version', 'r');
+            if (false !== $handle) {
+                self::$_lastestVersion = stream_get_contents($handle);
+                fclose($handle);
+            }
+        }
+
+        return self::$_lastestVersion;
+    }
 }
