@@ -15,20 +15,15 @@
  * @category   Zend
  * @package    Zend_Application
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: LocaleTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: LocaleTest.php 23838 2011-04-05 19:36:12Z ralph $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Application_Resource_LocaleTest::main');
 }
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /**
  * Zend_Loader_Autoloader
  */
@@ -38,7 +33,7 @@ require_once 'Zend/Loader/Autoloader.php';
  * @category   Zend
  * @package    Zend_Application
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Application
  */
@@ -117,7 +112,7 @@ class Zend_Application_Resource_LocaleTest extends PHPUnit_Framework_TestCase
         $this->assertTrue(Zend_Registry::isRegistered('Foo_Bar'));
         $this->assertSame(Zend_Registry::get('Foo_Bar'), $locale);
     }
-    
+
     public function testOptionsPassedToResourceAreUsedToSetLocaleState1()
     {
         $options = array(
@@ -128,11 +123,65 @@ class Zend_Application_Resource_LocaleTest extends PHPUnit_Framework_TestCase
         $resource->setBootstrap($this->bootstrap);
         $resource->init();
         $locale   = $resource->getLocale();
-        
+
         // This test will fail if your configured locale is kok_IN
-        $this->assertFalse('kok_IN' == $locale->__toString());
+        $this->assertEquals('kok_IN', $locale->__toString());
         $this->assertSame(Zend_Registry::get('Zend_Locale'), $locale);
     }
+
+    /**
+     * @group ZF-7058
+     */
+    public function testSetCache()
+    {
+        $cache = Zend_Cache::factory('Core', 'Black Hole', array(
+            'lifetime' => 120,
+            'automatic_serialization' => true
+        ));
+
+        $config = array(
+            'default' => 'fr_FR',
+            'cache' => $cache,
+        );
+        $resource = new Zend_Application_Resource_Locale($config);
+        $resource->init();
+        $backend = Zend_Locale::getCache()->getBackend();
+        $this->assertType('Zend_Cache_Backend_BlackHole', $backend);
+        Zend_Locale::removeCache();
+    }
+
+    /**
+     * @group ZF-7058
+     */
+    public function testSetCacheFromCacheManager()
+    {
+        $configCache = array(
+            'memory' => array(
+                'frontend' => array(
+                    'name' => 'Core',
+                    'options' => array(
+                        'lifetime' => 120,
+                        'automatic_serialization' => true
+                    )
+                ),
+                'backend' => array(
+                    'name' => 'Black Hole'
+                )
+            )
+        );
+        $this->bootstrap->registerPluginResource('cachemanager', $configCache);
+        $this->assertFalse(Zend_Locale::hasCache());
+
+        $config = array(
+            'bootstrap' => $this->bootstrap,
+            'cache' => 'memory',
+        );
+        $resource = new Zend_Application_Resource_Locale($config);
+        $resource->init();
+
+        $this->assertTrue(Zend_Locale::hasCache());
+        Zend_Locale::removeCache();
+    }
 }
 
 if (PHPUnit_MAIN_METHOD == 'Zend_Application_Resource_LocaleTest::main') {
