@@ -15,16 +15,11 @@
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: HttpTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: HttpTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 // Call Zend_Controller_Response_HttpTest::main() if this source file is executed directly.
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Controller_Response_HttpTest::main');
@@ -37,7 +32,7 @@ require_once 'Zend/Controller/Response/Exception.php';
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Controller
  * @group      Zend_Controller_Response
@@ -57,7 +52,6 @@ class Zend_Controller_Response_HttpTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Controller_Response_HttpTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
@@ -134,7 +128,7 @@ class Zend_Controller_Response_HttpTest extends PHPUnit_Framework_TestCase
 
         $this->_response->clearHeader('Connection');
         $updated_headers  = $this->_response->getHeaders();
-        
+
         $this->assertFalse($original_headers == $updated_headers);
     }
 
@@ -167,7 +161,7 @@ class Zend_Controller_Response_HttpTest extends PHPUnit_Framework_TestCase
 
         $this->_response->clearRawHeader('HTTP/1.0 404 Not Found');
         $updatedHeadersRaw  = $this->_response->getRawHeaders();
-        
+
         $this->assertFalse($originalHeadersRaw == $updatedHeadersRaw);
     }
 
