@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: TestCommon.php 21079 2010-02-18 18:15:49Z tech13 $
+ * @version    $Id: TestCommon.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 
@@ -36,14 +36,15 @@ require_once 'Zend/Registry.php';
  */
 require_once 'Zend/Db/Table.php';
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
+
+
 
 
 /**
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 abstract class Zend_Db_Table_TestCommon extends Zend_Db_Table_TestSetup
@@ -778,8 +779,9 @@ abstract class Zend_Db_Table_TestCommon extends Zend_Db_Table_TestSetup
 
     /**
      * See ZF-1739 in our issue tracker.
+     * @group ZF-1739
      */
-    public function testTableInsertMemoryUsageZf1739()
+    public function testTableInsertWithHighMemoryUsage()
     {
         $this->markTestSkipped('Very slow test inserts thousands of rows');
 
@@ -808,6 +810,50 @@ abstract class Zend_Db_Table_TestCommon extends Zend_Db_Table_TestSetup
         $mem_delta = $mem2-$mem1;
         $this->assertThat($mem_delta, $this->lessThan(513));
     }
+    
+    /**
+     * @group ZF-2953
+     */
+    public function testTableInsertWithEmptyValueAsPrimaryKey()
+    {
+        $table = $this->_table['bugs'];
+        $row = array (
+            'bug_description' => 'New bug',
+            'bug_status'      => 'NEW',
+            'created_on'      => '2007-04-02',
+            'updated_on'      => '2007-04-02',
+            'reported_by'     => 'micky',
+            'assigned_to'     => 'goofy',
+            'verified_by'     => 'dduck'
+        );
+        
+        // empty string
+        $row['bug_id'] = '';
+        $insertResult = $table->insert($row);
+        $this->assertTrue(is_numeric($insertResult), 'Empty string did not return assigned primary key');
+        
+        // false (bool)
+        $row['bug_id'] = false;
+        $insertResult = $table->insert($row);
+        $this->assertTrue(is_numeric($insertResult), 'Bool false did not return assigned primary key');
+
+        // empty array
+        $row['bug_id'] = array();
+        $insertResult = $table->insert($row);
+        $this->assertTrue(is_numeric($insertResult), 'Empty array did not return assigned primary key');
+        
+        // zero '0'
+        $row['bug_id'] = '0';
+        $table->delete('bug_id > 0'); // clear table
+        $insertResult = $table->insert($row);
+        $this->assertEquals('0', $insertResult, 'Zero string did not return assigned primary key');
+        
+        // zero 0
+        $row['bug_id'] = 0;
+        $table->delete('bug_id > 0'); // clear table
+        $insertResult = $table->insert($row);
+        $this->assertEquals('0', $insertResult, 'Zero int did not return assigned primary key');
+    }
 
     public function testTableUpdate()
     {
@@ -1638,4 +1684,52 @@ abstract class Zend_Db_Table_TestCommon extends Zend_Db_Table_TestSetup
     {
         return array('stuff' => 'information');
     }
+
+    /**
+     * @group ZF-7042
+     * @group ZF-10778
+     */
+    public function testCacheIdGeneratedToMetadata()
+    {
+        /**
+         * @see Zend_Cache
+         */
+        require_once 'Zend/Cache.php';
+
+        /**
+         * @see Zend_Cache_Backend_BlackHole
+         */
+        require_once 'Zend/Cache/Backend/BlackHole.php';
+
+        Zend_Db_Table::setDefaultAdapter($this->_db);
+        $dbConfig     = $this->_db->getConfig();
+        $cacheId = md5(
+                (isset($dbConfig['port']) ? ':'.$dbConfig['port'] : null)
+                . (isset($dbConfig['host']) ? ':'.$dbConfig['host'] : null)
+                . '/'.$dbConfig['dbname'].':.cache_metadata'
+                );
+
+        $metadata = array('id' => array('PRIMARY' => true));
+        $cacheBackend = $this->getMock('Zend_Cache_Backend_BlackHole');
+        $cacheBackend->expects($this->any())
+                     ->method('load')
+                     ->with($this->equalTo($cacheId))
+                     ->will($this->returnValue($metadata));
+
+        $cache = Zend_Cache::factory('Core', $cacheBackend, array('automatic_serialization' => false));
+        Zend_Db_Table_Abstract::setDefaultMetadataCache($cache);
+
+        $this->_util->createTable('cache_metadata', array(
+            'id'   => 'IDENTITY',
+            'name' => 'VARCHAR(32)'
+        ));
+        $configTable = array(
+            'name'    => 'cache_metadata',
+            'primary' => 'id'
+        );
+        $table = new Zend_Db_Table($configTable);
+        $table->info(Zend_Db_Table::METADATA);
+        $this->_util->dropTable('cache_metadata');
+        Zend_Db_Table_Abstract::setDefaultMetadataCache(null);
+    }
 }
