@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Http
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: CommonHttpTests.php 21778 2010-04-06 11:19:35Z shahar $
+ * @version    $Id: CommonHttpTests.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 // Read local configuration
@@ -27,8 +27,6 @@ if (! defined('TESTS_ZEND_HTTP_CLIENT_BASEURI') &&
     require_once 'TestConfiguration.php';
 }
 
-require_once realpath(dirname(__FILE__) . '/../../../') . '/TestHelper.php';
-
 require_once 'Zend/Http/Client.php';
 
 require_once 'Zend/Uri/Http.php';
@@ -50,7 +48,7 @@ require_once 'Zend/Uri/Http.php';
  * @category   Zend
  * @package    Zend_Http_Client
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Http
  * @group      Zend_Http_Client
@@ -237,9 +235,9 @@ abstract class Zend_Http_Client_CommonHttpTests extends PHPUnit_Framework_TestCa
             'specialChars' => '<>$+ &?=[]^%',
             'array' => array('firstItem', 'secondItem', '3rdItem')
         );
-        
+
         $headers = array("X-Foo" => "bar");
-        
+
         $this->client->setParameterPost($params);
         $this->client->setParameterGet($params);
         $this->client->setHeaders($headers);
@@ -739,6 +737,10 @@ abstract class Zend_Http_Client_CommonHttpTests extends PHPUnit_Framework_TestCa
      */
     public function testUploadRawData()
     {
+        if (!ini_get('file_uploads')) {
+            $this->markTestSkipped('File uploads disabled.');
+        }
+
         $this->client->setUri($this->baseuri. 'testUploads.php');
 
         $rawdata = file_get_contents(__FILE__);
@@ -755,6 +757,10 @@ abstract class Zend_Http_Client_CommonHttpTests extends PHPUnit_Framework_TestCa
      */
     public function testUploadLocalFile()
     {
+        if (!ini_get('file_uploads')) {
+            $this->markTestSkipped('File uploads disabled.');
+        }
+
         $this->client->setUri($this->baseuri. 'testUploads.php');
         $this->client->setFileUpload(__FILE__, 'uploadfile', null, 'text/x-foo-bar');
         $res = $this->client->request('POST');
@@ -767,6 +773,10 @@ abstract class Zend_Http_Client_CommonHttpTests extends PHPUnit_Framework_TestCa
 
     public function testUploadLocalDetectMime()
     {
+        if (!ini_get('file_uploads')) {
+            $this->markTestSkipped('File uploads disabled.');
+        }
+
         $detect = null;
         if (function_exists('finfo_file')) {
             $f = @finfo_open(FILEINFO_MIME);
@@ -795,6 +805,10 @@ abstract class Zend_Http_Client_CommonHttpTests extends PHPUnit_Framework_TestCa
 
     public function testUploadNameWithSpecialChars()
     {
+        if (!ini_get('file_uploads')) {
+            $this->markTestSkipped('File uploads disabled.');
+        }
+
         $this->client->setUri($this->baseuri. 'testUploads.php');
 
         $rawdata = file_get_contents(__FILE__);
@@ -823,6 +837,10 @@ abstract class Zend_Http_Client_CommonHttpTests extends PHPUnit_Framework_TestCa
      */
     public function testMutipleFilesWithSameFormNameZF5744()
     {
+        if (!ini_get('file_uploads')) {
+            $this->markTestSkipped('File uploads disabled.');
+        }
+
         $rawData = 'Some test raw data here...';
 
         $this->client->setUri($this->baseuri . 'testUploads.php');
@@ -854,113 +872,130 @@ abstract class Zend_Http_Client_CommonHttpTests extends PHPUnit_Framework_TestCa
         $expected = $this->_getTestFileContents('ZF4238-zerolineresponse.txt');
         $this->assertEquals($expected, $got);
     }
-    
+
     public function testStreamResponse()
     {
         if(!($this->client->getAdapter() instanceof Zend_Http_Client_Adapter_Stream)) {
               $this->markTestSkipped('Current adapter does not support streaming');
-              return;   
+              return;
         }
         $this->client->setUri($this->baseuri . 'staticFile.jpg');
         $this->client->setStream();
 
         $response = $this->client->request();
-        
+
         $this->assertTrue($response instanceof Zend_Http_Response_Stream, 'Request did not return stream response!');
         $this->assertTrue(is_resource($response->getStream()), 'Request does not contain stream!');
-        
+
         $stream_name = $response->getStreamName();
-     
+
         $stream_read = stream_get_contents($response->getStream());
         $file_read = file_get_contents($stream_name);
-        
+
         $expected = $this->_getTestFileContents('staticFile.jpg');
 
         $this->assertEquals($expected, $stream_read, 'Downloaded stream does not seem to match!');
         $this->assertEquals($expected, $file_read, 'Downloaded file does not seem to match!');
     }
-    
+
     public function testStreamResponseBody()
     {
         if(!($this->client->getAdapter() instanceof Zend_Http_Client_Adapter_Stream)) {
               $this->markTestSkipped('Current adapter does not support streaming');
-              return;   
+              return;
         }
         $this->client->setUri($this->baseuri . 'staticFile.jpg');
         $this->client->setStream();
 
         $response = $this->client->request();
-        
+
         $this->assertTrue($response instanceof Zend_Http_Response_Stream, 'Request did not return stream response!');
         $this->assertTrue(is_resource($response->getStream()), 'Request does not contain stream!');
-        
+
         $body = $response->getBody();
-        
+
         $expected = $this->_getTestFileContents('staticFile.jpg');
         $this->assertEquals($expected, $body, 'Downloaded stream does not seem to match!');
     }
-    
+
     public function testStreamResponseNamed()
     {
         if(!($this->client->getAdapter() instanceof Zend_Http_Client_Adapter_Stream)) {
               $this->markTestSkipped('Current adapter does not support streaming');
-              return;   
+              return;
         }
         $this->client->setUri($this->baseuri . 'staticFile.jpg');
         $outfile = tempnam(sys_get_temp_dir(), "outstream");
         $this->client->setStream($outfile);
 
         $response = $this->client->request();
-        
+
         $this->assertTrue($response instanceof Zend_Http_Response_Stream, 'Request did not return stream response!');
         $this->assertTrue(is_resource($response->getStream()), 'Request does not contain stream!');
-        
+
         $this->assertEquals($outfile, $response->getStreamName());
-     
+
         $stream_read = stream_get_contents($response->getStream());
         $file_read = file_get_contents($outfile);
-        
+
         $expected = $this->_getTestFileContents('staticFile.jpg');
 
         $this->assertEquals($expected, $stream_read, 'Downloaded stream does not seem to match!');
         $this->assertEquals($expected, $file_read, 'Downloaded file does not seem to match!');
     }
-       
+
     public function testStreamRequest()
     {
         if(!($this->client->getAdapter() instanceof Zend_Http_Client_Adapter_Stream)) {
               $this->markTestSkipped('Current adapter does not support streaming');
-              return;   
+              return;
         }
-        $data = fopen(dirname(realpath(__FILE__)) . DIRECTORY_SEPARATOR . '_files' . DIRECTORY_SEPARATOR . 'staticFile.jpg', "r"); 
+        $data = fopen(dirname(realpath(__FILE__)) . DIRECTORY_SEPARATOR . '_files' . DIRECTORY_SEPARATOR . 'staticFile.jpg', "r");
         $res = $this->client->setRawData($data, 'image/jpeg')->request('PUT');
         $expected = $this->_getTestFileContents('staticFile.jpg');
         $this->assertEquals($expected, $res->getBody(), 'Response body does not contain the expected data');
     }
-    
+
     /**
      * Test that we can deal with double Content-Length headers
-     * 
+     *
      * @link http://framework.zend.com/issues/browse/ZF-9404
      */
     public function testZF9404DoubleContentLengthHeader()
     {
         $this->client->setUri($this->baseuri . 'ZF9404-doubleContentLength.php');
         $expect = filesize(dirname(realpath(__FILE__)) . DIRECTORY_SEPARATOR . '_files' . DIRECTORY_SEPARATOR . 'ZF9404-doubleContentLength.php');
-        
+
         $response = $this->client->request();
         if (! $response->isSuccessful()) {
             throw new ErrorException("Error requesting test URL");
         }
-        
+
         $clen = $response->getHeader('content-length');
         if (! (is_array($clen))) {
             $this->markTestSkipped("Didn't get multiple Content-length headers");
         }
-        
+
         $this->assertEquals($expect, strlen($response->getBody()));
     }
-    
+
+    /**
+     * @group ZF-10645
+     */
+    public function testPutRequestsHonorSpecifiedContentType()
+    {
+        $this->client->setUri($this->baseuri . 'ZF10645-PutContentType.php');
+        $this->client->setMethod(Zend_Http_Client::PUT);
+        $data = array('foo' => 'bar');
+        $this->client->setRawData(http_build_query($data), 'text/html; charset=ISO-8859-1');
+
+        $response = $this->client->request();
+        $request  = $this->client->getLastRequest();
+
+        $this->assertContains('text/html; charset=ISO-8859-1', $request, $request);
+        $this->assertContains('REQUEST_METHOD: PUT', $response->getBody(), $response->getBody());
+    }
+
     /**
      * Internal helpder function to get the contents of test files
      *
