@@ -15,13 +15,11 @@
  * @category   Zend
  * @package    Zend_Http_Client
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: StaticTest.php 21920 2010-04-16 22:10:02Z dragonbe $
+ * @version    $Id: StaticTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-require_once realpath(dirname(__FILE__) . '/../../../') . '/TestHelper.php';
-
 require_once 'Zend/Http/Client.php';
 
 require_once 'Zend/Http/Client/Adapter/Test.php';
@@ -35,7 +33,7 @@ require_once 'Zend/Http/Client/Adapter/Test.php';
  * @category   Zend
  * @package    Zend_Http_Client
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Http
  * @group      Zend_Http_Client
@@ -292,6 +290,50 @@ class Zend_Http_Client_StaticTest extends PHPUnit_Framework_TestCase
         $this->_client->setCookieJar('cookiejar');
     }
 
+    /**
+     * Test that when the encodecookies flag is set to FALSE, cookies captured
+     * from a response by Zend_Http_CookieJar are not encoded
+     *
+     * @group ZF-1850
+     */
+    public function testCaptureCookiesNoEncodeZF1850()
+    {
+        $cookieName = "cookieWithSpecialChars";
+        $cookieValue = "HID=XXXXXX&UN=XXXXXXX&UID=XXXXX";
+
+        $adapter = new Zend_Http_Client_Adapter_Test();
+        $adapter->setResponse(
+        	"HTTP/1.0 200 OK\r\n" .
+            "Content-type: text/plain\r\n" .
+            "Content-length: 2\r\n" .
+            "Connection: close\r\n" .
+            "Set-Cookie: $cookieName=$cookieValue; path=/\r\n" .
+            "\r\n" .
+            "OK"
+        );
+
+        $this->_client->setUri('http://example.example/test');
+        $this->_client->setConfig(array(
+            'adapter'       => $adapter,
+            'encodecookies' => false
+        ));
+
+        $this->_client->setCookieJar();
+
+        // First request is expected to set the cookie
+        $this->_client->request();
+
+        // Next request should contain the cookie
+        $this->_client->request();
+
+        $request = $this->_client->getLastRequest();
+        if (! preg_match("/^Cookie: $cookieName=([^;]+)/m", $request, $match)) {
+            $this->fail("Could not find cookie in request");
+        }
+
+        $this->assertEquals($cookieValue, $match[1]);
+    }
+
     /**
      * Configuration Handling
      */
@@ -542,10 +584,10 @@ class Zend_Http_Client_StaticTest extends PHPUnit_Framework_TestCase
         // if the bug exists this call should creates a fatal error
         $client->setAuth(false);
     }
-    
+
 	/**
      * Testing if the connection isn't closed
-     * 
+     *
      * @group ZF-9685
      */
     public function testOpenTempStreamWithValidFileDoesntThrowsException()
@@ -564,10 +606,10 @@ class Zend_Http_Client_StaticTest extends PHPUnit_Framework_TestCase
 		// @todo verify link is still active
 		return;
     }
-    
+
     /**
      * Testing if the connection can be closed
-     * 
+     *
      * @group ZF-9685
      */
     public function testOpenTempStreamWithBogusFileClosesTheConnection()
