@@ -15,16 +15,13 @@
  * @category   Zend
  * @package    Zend_Http_Client
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: TestAdapterTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: TestAdapterTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-require_once realpath(dirname(__FILE__) . '/../../../') . '/TestHelper.php';
-
 require_once 'Zend/Http/Client.php';
 require_once 'Zend/Http/Client/Adapter/Test.php';
-require_once 'PHPUnit/Framework/TestCase.php';
 
 /**
  * Exercises Zend_Http_Client_Adapter_Test
@@ -32,7 +29,7 @@ require_once 'PHPUnit/Framework/TestCase.php';
  * @category   Zend
  * @package    Zend_Http_Client
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Http
  * @group      Zend_Http_Client
