@@ -15,16 +15,11 @@
  * @category   Zend
  * @package    Zend_Json
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: JsonTest.php 22453 2010-06-18 18:17:52Z ralph $
+ * @version    $Id: JsonTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../TestHelper.php';
-
 /**
  * @see Zend_Json
  */
@@ -49,7 +44,7 @@ require_once 'Zend/Json/Decoder.php';
  * @category   Zend
  * @package    Zend_Json
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Json
  */
@@ -711,7 +706,7 @@ class Zend_JsonTest extends PHPUnit_Framework_TestCase
         }
 
         Zend_Json::$useBuiltinEncoderDecoder = true;
-        $this->assertEquals("[1.20, 1.68]", Zend_Json_Encode::encode(array(
+        $this->assertEquals("[1.20, 1.68]", Zend_Json_Encoder::encode(array(
             (float)"1,20", (float)"1,68"
         )));
     }
@@ -720,7 +715,7 @@ class Zend_JsonTest extends PHPUnit_Framework_TestCase
     {
         $this->markTestIncomplete('Test is not yet finished.');
     }
-    
+
     /**
      * @group ZF-8663
      */
@@ -728,12 +723,12 @@ class Zend_JsonTest extends PHPUnit_Framework_TestCase
     {
         $source = "</foo><foo>bar</foo>";
         $target = '"<\\/foo><foo>bar<\\/foo>"';
-        
+
         // first test ext/json
         Zend_Json::$useBuiltinEncoderDecoder = false;
         $this->assertEquals($target, Zend_Json::encode($source));
     }
-    
+
     /**
      * @group ZF-8663
      */
@@ -741,12 +736,12 @@ class Zend_JsonTest extends PHPUnit_Framework_TestCase
     {
         $source = "</foo><foo>bar</foo>";
         $target = '"<\\/foo><foo>bar<\\/foo>"';
-        
+
         // first test ext/json
         Zend_Json::$useBuiltinEncoderDecoder = true;
         $this->assertEquals($target, Zend_Json::encode($source));
     }
-    
+
     /**
      * @group ZF-8918
      * @expectedException Zend_Json_Exception
