@@ -15,17 +15,11 @@
  * @category   Zend
  * @package    Zend_Rest
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: RouteTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: RouteTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-/** Test helper */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
-require_once "PHPUnit/Framework/TestCase.php";
-require_once "PHPUnit/Framework/TestSuite.php";
-
 /** Zend_Rest_Route */
 require_once 'Zend/Rest/Route.php';
 
@@ -44,7 +38,7 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
  * @category   Zend
  * @package    Zend_Rest
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Rest
  */
@@ -63,7 +57,6 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Rest_RouteTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
@@ -192,6 +185,22 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('active', $values['status']);
     }
     
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulApp_GET_user_index_withParam_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('GET', '/user/index/the%2Bemail%40address/email%2Btest%40example.com');
+        $values = $this->_invokeRouteMatch($request);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('default', $values['module']);
+        $this->assertEquals('user', $values['controller']);
+        $this->assertEquals('index', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['the+email@address']);
+    }
+
     public function test_RESTfulApp_GET_project_byIdentifier()
     {
         $request = $this->_buildRequest('GET', '/project/zendframework');
@@ -230,7 +239,51 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('get', $values['action']);
         $this->assertEquals('zend framework', $values['id']);
     }
-    
+
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulApp_GET_project_byIdentifier_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('GET', '/project/email%2Btest%40example.com');
+        $values = $this->_invokeRouteMatch($request);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('default', $values['module']);
+        $this->assertEquals('project', $values['controller']);
+        $this->assertEquals('get', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['id']);
+    }
+
+    public function test_RESTfulApp_HEAD_project_byIdentifier()
+    {
+        $request = $this->_buildRequest('HEAD', '/project/lcrouch');
+        $values = $this->_invokeRouteMatch($request);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('default', $values['module']);
+        $this->assertEquals('project', $values['controller']);
+        $this->assertEquals('head', $values['action']);
+    }
+
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulApp_HEAD_project_byIdentifier_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('HEAD', '/project/email%2Btest%40example.com');
+        $values = $this->_invokeRouteMatch($request);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('default', $values['module']);
+        $this->assertEquals('project', $values['controller']);
+        $this->assertEquals('head', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['id']);
+    }
+
     public function test_RESTfulApp_GET_project_edit()
     {
         $request = $this->_buildRequest('GET', '/project/zendframework/edit');
@@ -244,6 +297,22 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('zendframework', $values['id']);
     }
 
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulApp_GET_project_edit_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('GET', '/project/email%2Btest%40example.com/edit');
+        $values = $this->_invokeRouteMatch($request);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('default', $values['module']);
+        $this->assertEquals('project', $values['controller']);
+        $this->assertEquals('edit', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['id']);
+    }
+
     public function test_RESTfulApp_PUT_user_byIdentifier()
     {
         $request = $this->_buildRequest('PUT', '/mod/user/lcrouch');
@@ -257,6 +326,22 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('lcrouch', $values['id']);
     }
 
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulApp_PUT_user_byIdentifier_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('PUT', '/mod/user/email%2Btest%40example.com');
+        $values = $this->_invokeRouteMatch($request);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('mod', $values['module']);
+        $this->assertEquals('user', $values['controller']);
+        $this->assertEquals('put', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['id']);
+    }
+
     public function test_RESTfulApp_POST_user()
     {
         $request = $this->_buildRequest('POST', '/mod/user');
@@ -282,6 +367,22 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('lcrouch', $values['id']);
     }
 
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulApp_DELETE_user_byIdentifier_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('DELETE', '/mod/user/email%2Btest%40example.com');
+        $values = $this->_invokeRouteMatch($request);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('mod', $values['module']);
+        $this->assertEquals('user', $values['controller']);
+        $this->assertEquals('delete', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['id']);
+    }
+
     public function test_RESTfulApp_POST_user_with_identifier_doesPUT()
     {
         $request = $this->_buildRequest('POST', '/mod/user/lcrouch');
@@ -295,6 +396,22 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('lcrouch', $values['id']);
     }
 
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulApp_POST_user_with_identifier_urlencodedWithPlusSymbol_doesPUT()
+    {
+        $request = $this->_buildRequest('POST', '/mod/user/email%2Btest%40example.com');
+        $values = $this->_invokeRouteMatch($request);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('mod', $values['module']);
+        $this->assertEquals('user', $values['controller']);
+        $this->assertEquals('put', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['id']);
+    }
+
     public function test_RESTfulApp_overload_POST_with_method_param_PUT()
     {
         $request = $this->_buildRequest('POST', '/mod/user');
@@ -322,6 +439,23 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('lcrouch', $values['id']);
     }
 
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulApp_overload_POST_with_http_header_DELETE_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('POST', '/mod/user/email%2Btest%40example.com');
+        $request->setHeader('X-HTTP-Method-Override', 'DELETE');
+        $values = $this->_invokeRouteMatch($request);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('mod', $values['module']);
+        $this->assertEquals('user', $values['controller']);
+        $this->assertEquals('delete', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['id']);
+    }
+
     public function test_RESTfulApp_route_chaining()
     {
         $request = $this->_buildRequest('GET', '/api/user/lcrouch');
@@ -342,6 +476,29 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals("lcrouch", $routedRequest->getParam("id"));
     }
 
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulApp_route_chaining_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('GET', '/api/user/email%2Btest%40example.com');
+        $this->_front->setRequest($request);
+
+        $router = $this->_front->getRouter();
+        $router->removeDefaultRoutes();
+
+        $nonRESTRoute = new Zend_Controller_Router_Route('api');
+        $RESTRoute = new Zend_Rest_Route($this->_front);
+        $router->addRoute("api", $nonRESTRoute->chain($RESTRoute));
+
+        $routedRequest = $router->route($request);
+
+        $this->assertEquals("default", $routedRequest->getParam("module"));
+        $this->assertEquals("user", $routedRequest->getParam("controller"));
+        $this->assertEquals("get", $routedRequest->getParam("action"));
+        $this->assertEquals("email+test@example.com", $routedRequest->getParam("id"));
+    }
+
     public function test_RESTfulModule_GET_user_index()
     {
         $request = $this->_buildRequest('GET', '/mod/user/index');
@@ -355,6 +512,23 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('index', $values['action']);
     }
 
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulModule_GET_user_index_withParam_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('GET', '/mod/user/index/the%2Bemail%40address/email%2Btest%40example.com');
+        $config = array('mod');
+        $values = $this->_invokeRouteMatch($request, $config);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('mod', $values['module']);
+        $this->assertEquals('user', $values['controller']);
+        $this->assertEquals('index', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['the+email@address']);
+    }
+
     public function test_RESTfulModule_GET_user()
     {
         $request = $this->_buildRequest('GET', '/mod/user/1234');
@@ -368,6 +542,23 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('get', $values['action']);
     }
 
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulModule_GET_user_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('GET', '/mod/user/email%2Btest%40example.com');
+        $config = array('mod');
+        $values = $this->_invokeRouteMatch($request, $config);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('mod', $values['module']);
+        $this->assertEquals('user', $values['controller']);
+        $this->assertEquals('get', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['id']);
+    }
+
     public function test_RESTfulModule_POST_user()
     {
         $request = $this->_buildRequest('POST', '/mod/user');
@@ -404,6 +595,23 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('lcrouch', $values['id']);
     }
 
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulModule_PUT_user_byIdentifier_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('PUT', '/mod/user/email%2Btest%40example.com');
+        $config = array('mod');
+        $values = $this->_invokeRouteMatch($request, $config);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('mod', $values['module']);
+        $this->assertEquals('user', $values['controller']);
+        $this->assertEquals('put', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['id']);
+    }
+
     public function test_RESTfulModule_DELETE_user_byIdentifier()
     {
         $request = $this->_buildRequest('DELETE', '/mod/user/lcrouch');
@@ -418,6 +626,23 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('lcrouch', $values['id']);
     }
 
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulModule_DELETE_user_byIdentifier_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('DELETE', '/mod/user/email%2Btest%40example.com');
+        $config = array('mod');
+        $values = $this->_invokeRouteMatch($request, $config);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('mod', $values['module']);
+        $this->assertEquals('user', $values['controller']);
+        $this->assertEquals('delete', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['id']);
+    }
+
     public function test_RESTfulController_GET_user_index()
     {
         $request = $this->_buildRequest('GET', '/mod/user/index');
@@ -462,6 +687,23 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('get', $values['action']);
     }
 
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulController_GET_user_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('GET', '/mod/user/email%2Btest%40example.com');
+        $config = array('mod'=>array('user'));
+        $values = $this->_invokeRouteMatch($request, $config);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('mod', $values['module']);
+        $this->assertEquals('user', $values['controller']);
+        $this->assertEquals('get', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['id']);
+    }
+
     public function test_RESTfulController_POST_user()
     {
         $request = $this->_buildRequest('POST', '/mod/user');
@@ -516,6 +758,23 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('lcrouch', $values['id']);
     }
 
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulController_PUT_user_byIdentifier_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('PUT', '/mod/user/email%2Btest%40example.com');
+        $config = array('mod'=>array('user'));
+        $values = $this->_invokeRouteMatch($request, $config);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('mod', $values['module']);
+        $this->assertEquals('user', $values['controller']);
+        $this->assertEquals('put', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['id']);
+    }
+
     public function test_RESTfulController_DELETE_user_byIdentifier()
     {
         $request = $this->_buildRequest('DELETE', '/mod/user/lcrouch');
@@ -530,6 +789,23 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('lcrouch', $values['id']);
     }
 
+    /**
+     * @group ZF-10964
+     */
+    public function test_RESTfulController_DELETE_user_byIdentifier_urlencodedWithPlusSymbol()
+    {
+        $request = $this->_buildRequest('DELETE', '/mod/user/email%2Btest%40example.com');
+        $config = array('mod');
+        $values = $this->_invokeRouteMatch($request, $config);
+
+        $this->assertType('array', $values);
+        $this->assertTrue(isset($values['module']));
+        $this->assertEquals('mod', $values['module']);
+        $this->assertEquals('user', $values['controller']);
+        $this->assertEquals('delete', $values['action']);
+        $this->assertEquals('email+test@example.com', $values['id']);
+    }
+
     public function test_assemble_plain_ignores_action()
     {
         $route = new Zend_Rest_Route($this->_front, array(), array());
@@ -570,6 +846,94 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('mod/user/index/foo/bar is n!ice', $url);
     }
     
+    /**
+     * @group ZF-9823
+     */
+    public function test_assemble_edit_with_module_appends_action_after_id()
+    {
+        $route = new Zend_Rest_Route($this->_front, array(), array());
+        $params = array('module'=>'mod', 'controller'=>'users', 'action'=>'edit', 'id'=>1);
+        $url = $route->assemble($params);
+        $this->assertEquals('mod/users/1/edit', $url);
+    }
+
+    /**
+     * @group ZF-9823
+     */
+    public function test_assemble_edit_without_module_appends_action_after_id()
+    {
+        $route = new Zend_Rest_Route($this->_front, array(), array());
+        $params = array('controller'=>'users', 'action'=>'edit', 'id'=>1);
+        $url = $route->assemble($params);
+        $this->assertEquals('users/1/edit', $url);
+    }
+
+    /**
+     * @group ZF-9823
+     */
+    public function test_assemble_new_with_module_appends_action()
+    {
+        $route = new Zend_Rest_Route($this->_front, array(), array());
+        $params = array('module'=>'mod', 'controller'=>'users', 'action'=>'new');
+        $url = $route->assemble($params);
+        $this->assertEquals('mod/users/new', $url);
+    }
+
+    /**
+     * @group ZF-9823
+     */
+    public function test_assemble_new_without_module_appends_action()
+    {
+        $route = new Zend_Rest_Route($this->_front, array(), array());
+        $params = array('controller'=>'users', 'action'=>'new');
+        $url = $route->assemble($params);
+        $this->assertEquals('users/new', $url);
+    }
+
+    /**
+     * @group ZF-9823
+     */
+    public function test_assemble_random_action_with_module_removes_action()
+    {
+        $route = new Zend_Rest_Route($this->_front, array(), array());
+        $params = array('module'=>'mod', 'controller'=>'users', 'action'=>'newbar');
+        $url = $route->assemble($params);
+        $this->assertNotEquals('mod/users/newbar', $url);
+    }
+
+    /**
+     * @group ZF-9823
+     */
+    public function test_assemble_random_action_without_module_removes_action()
+    {
+        $route = new Zend_Rest_Route($this->_front, array(), array());
+        $params = array('controller'=>'users', 'action'=>'newbar');
+        $url = $route->assemble($params);
+        $this->assertNotEquals('users/newbar', $url);
+    }
+
+    /**
+     * @group ZF-9823
+     */
+    public function test_assemble_with_module_honors_index_parameter_with_resource_id_and_extra_parameters()
+    {
+        $route = new Zend_Rest_Route($this->_front, array(), array());
+        $params = array('module'=>'mod', 'controller'=>'users', 'id' => 1, 'extra'=>'parameter', 'another' => 'parameter', 'index' => true);
+        $url = $route->assemble($params, false, false);
+        $this->assertEquals('mod/users/index/1/extra/parameter/another/parameter', $url);
+    }
+
+    /**
+     * @group ZF-9823
+     */
+    public function test_assemble_without_module_honors_index_parameter_with_resource_id_and_extra_parameters()
+    {
+        $route = new Zend_Rest_Route($this->_front, array(), array());
+        $params = array('controller'=>'users', 'id' => 1, 'extra'=>'parameter', 'another' => 'parameter', 'index' => true);
+        $url = $route->assemble($params, false, false);
+        $this->assertEquals('users/index/1/extra/parameter/another/parameter', $url);
+    }
+
     private function _buildRequest($method, $uri)
     {
         $request = new Zend_Controller_Request_HttpTestCase();
