@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Search_Lucene
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: DocumentTest.php 21944 2010-04-19 07:25:54Z alexander $
+ * @version    $Id: DocumentTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 /**
@@ -40,16 +40,11 @@ require_once 'Zend/Search/Lucene/Document/Pptx.php';
  */
 require_once 'Zend/Search/Lucene/Document/Xlsx.php';
 
-/**
- * PHPUnit test case
- */
-require_once 'PHPUnit/Framework/TestCase.php';
-
 /**
  * @category   Zend
  * @package    Zend_Search_Lucene
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Search_Lucene
  */
@@ -209,7 +204,7 @@ class Zend_Search_Lucene_DocumentTest extends PHPUnit_Framework_TestCase
 
         $hits = $index->find('ZendFramework');
         $this->assertEquals(count($hits), 1);
-        
+
         unset($index);
         $this->_clearDirectory(dirname(__FILE__) . '/_index/_files');
     }
@@ -319,6 +314,15 @@ class Zend_Search_Lucene_DocumentTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($xlsxDocument->getFieldValue('body') != '');
         $this->assertTrue( strpos($xlsxDocument->getFieldValue('body'), 'ipsum') !== false );
     }
+
+    /**
+     * @group ZF-10686
+     */
+    public function testLoadHtmlWithAttributesInTagHTML()
+    {
+        $doc = Zend_Search_Lucene_Document_Html::loadHTML('<HTML lang="en_US"><HEAD><TITLE>Page title</TITLE></HEAD><BODY>Document body.</BODY></HTML>');
+        $this->assertEquals('Page title ', $doc->title);
+    }
 }
 
 
