@@ -15,16 +15,11 @@
  * @category   Zend
  * @package    Zend_Soap
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ServerTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: ServerTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-require_once dirname(__FILE__)."/../../TestHelper.php";
-
-/** PHPUnit Test Case */
-require_once "PHPUnit/Framework/TestCase.php";
-
 /** Zend_Soap_Server */
 require_once 'Zend/Soap/Server.php';
 
@@ -39,7 +34,7 @@ require_once "Zend/Config.php";
  * @package    Zend_Soap
  * @subpackage UnitTests
  * @uses       Zend_Server_Interface
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Soap
  * @group      Zend_Soap_Server
@@ -88,6 +83,21 @@ class Zend_Soap_ServerTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($server->getOptions() == $options);
     }
 
+    /**
+     * @group ZF-9816
+     */
+    public function testSetOptionsWithFeaturesOption()
+    {
+        $server = new Zend_Soap_Server(null, array(
+            'features' => SOAP_SINGLE_ELEMENT_ARRAYS
+        ));
+
+        $this->assertEquals(
+            SOAP_SINGLE_ELEMENT_ARRAYS,
+            $server->getSoapFeatures()
+        );
+    }
+
     public function testSetWsdlViaOptionsArrayIsPossible()
     {
         $server = new Zend_Soap_Server();
