@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: CycleTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: CycleTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 // Call Zend_View_Helper_CycleTest::main() if this source file is executed directly.
@@ -25,12 +25,6 @@ if (! defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_View_Helper_CycleTest::main");
 }
 
-require_once dirname(dirname(dirname(dirname(__FILE__)))) . '/TestHelper.php';
-
-require_once "PHPUnit/Framework/TestCase.php";
-
-require_once "PHPUnit/Framework/TestSuite.php";
-
 /** Zend_View_Helper_Cycle */
 require_once 'Zend/View/Helper/Cycle.php';
 
@@ -40,7 +34,7 @@ require_once 'Zend/View/Helper/Cycle.php';
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_View
  * @group      Zend_View_Helper
@@ -59,7 +53,6 @@ class Zend_View_Helper_CycleTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
         $suite = new PHPUnit_Framework_TestSuite("Zend_View_Helper_CycleTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
     }
