@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: FormRadioTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: FormRadioTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 // Call Zend_View_Helper_FormRadioTest::main() if this source file is executed directly.
@@ -25,8 +25,6 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_View_Helper_FormRadioTest::main");
 }
 
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 require_once 'Zend/View/Helper/FormRadio.php';
 require_once 'Zend/View.php';
 
@@ -38,7 +36,7 @@ require_once 'Zend/View.php';
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_View
  * @group      Zend_View_Helper
@@ -53,7 +51,6 @@ class Zend_View_Helper_FormRadioTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_View_Helper_FormRadioTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
@@ -113,7 +110,7 @@ class Zend_View_Helper_FormRadioTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-3206
+     * @group ZF-3206
      */
     public function testSpecifyingLabelPlacementShouldNotOverwriteValue()
     {
@@ -369,7 +366,7 @@ class Zend_View_Helper_FormRadioTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @issue ZF-5681
+     * @group ZF-5681
      */
     public function testRadioLabelDoesNotContainHardCodedStyle()
     {
